aboutsummaryrefslogtreecommitdiffstats
path: root/ui/gtk/file_dlg.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2017-04-05 12:15:27 -0700
committerGuy Harris <guy@alum.mit.edu>2017-04-05 19:16:22 +0000
commit357cfd3b035d1ba6438e82cc1cbec105874206b6 (patch)
tree58a77b4dc8e1192db6278716b320bf42a18ded8f /ui/gtk/file_dlg.c
parent1f94d34f43055ea47fc9426e1720bdb4b7397dd9 (diff)
A bunch of "{Mac} OS X" -> "macOS" changes.
Avoid anachronisms, however; there was no "macOS 10.0" or even "OS X 10.0", for example. It was "Mac OS X" until 10.8 (although 10.7 was sometimes called "OS X" and sometimes called "Mac OS X"), and it was "OS X" from 10.8 to 10.11. Change-Id: Ie4a848997dcc6c45c2245c1fb84ec526032375c3 Reviewed-on: https://code.wireshark.org/review/20933 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'ui/gtk/file_dlg.c')
-rw-r--r--ui/gtk/file_dlg.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/ui/gtk/file_dlg.c b/ui/gtk/file_dlg.c
index 72acf6029b..47e8938302 100644
--- a/ui/gtk/file_dlg.c
+++ b/ui/gtk/file_dlg.c
@@ -292,7 +292,7 @@ file_target_unwritable_ui(GtkWidget *chooser_w, char *cf_name)
ioctls (FS_IOC_GETFLAGS/FS_IOC_SETFLAGS in newer kernels,
EXT2_IOC_GETFLAGS/EXT2_IOC_SETFLAGS in older kernels - non-ext2
file systems that support those ioctls use the same values as ext2
- does), appears to be more like the *BSD/OS X "system immutable"
+ does), appears to be more like the *BSD/macOS "system immutable"
flag, as it can be set only by the superuser or by processes with
CAP_LINUX_IMMUTABLE, so it sounds as if it's not intended for
arbitrary users to set or clear. */
@@ -314,8 +314,8 @@ file_target_unwritable_ui(GtkWidget *chooser_w, char *cf_name)
GTK_MESSAGE_QUESTION,
GTK_BUTTONS_NONE,
#ifdef __APPLE__
- /* Stuff in the OS X UI calls files with the "user immutable" bit
- "locked"; pre-OS X Mac software might have had that notion and
+ /* Stuff in the macOS UI calls files with the "user immutable" bit
+ "locked"; the classic Mac OS might have had that notion and
called it "locked". */
"The file \"%s\" is locked.",
#else /* __APPLE__ */